Simulation Entry Points
=======================

.. contents::
   :depth: 2
   :local:
   :backlinks: none

Outline
-------

- What's in the engine?
- The command line interface
- The interactive interface
- Architecture for a distributed interface.
